@@ -45,13 +45,13 @@
 
 /* private class data
  */
-struct NAObjectActionClassPrivate {
+struct _NAObjectActionClassPrivate {
 	void *empty;						/* so that gcc -pedantic is happy */
 };
 
 /* private instance data
  */
-struct NAObjectActionPrivate {
+struct _NAObjectActionPrivate {
 	gboolean dispose_has_run;
 };
 
@@ -79,13 +79,17 @@ static guint        ifactory_object_get_version( const NAIFactoryObject *instanc
 static NADataGroup *ifactory_object_get_groups( const NAIFactoryObject *instance );
 static gboolean     ifactory_object_are_equal( const NAIFactoryObject *a, const NAIFactoryObject *b );
 static gboolean     ifactory_object_is_valid( const NAIFactoryObject *object );
-static void         ifactory_object_read_start( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static void         ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages );
 static guint        ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 static guint        ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
-static void         convert_pre_v2_action( NAIFactoryObject *instance );
-static void         deals_with_toolbar_label( NAIFactoryObject *instance );
+static void         icontext_iface_init( NAIContextInterface *iface );
+static gboolean     icontext_is_candidate( NAIContext *object, guint target, GList *selection );
+
+static gboolean     read_done_convert_v1_to_last( NAIFactoryObject *instance );
+static void         read_done_deals_with_toolbar_label( NAIFactoryObject *instance );
+
+static guint        write_done_write_profiles( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages );
 
 static gboolean     object_object_is_valid( const NAObjectAction *action );
 static gboolean     is_valid_label( const NAObjectAction *action );
@@ -122,6 +126,12 @@ register_type( void )
 		( GInstanceInitFunc ) instance_init
 	};
 
+	static const GInterfaceInfo icontext_iface_info = {
+		( GInterfaceInitFunc ) icontext_iface_init,
+		NULL,
+		NULL
+	};
+
 	static const GInterfaceInfo ifactory_object_iface_info = {
 		( GInterfaceInitFunc ) ifactory_object_iface_init,
 		NULL,
@@ -132,6 +142,8 @@ register_type( void )
 
 	type = g_type_register_static( NA_OBJECT_ITEM_TYPE, "NAObjectAction", &info, 0 );
 
+	g_type_add_interface_static( type, NA_ICONTEXT_TYPE, &icontext_iface_info );
+
 	g_type_add_interface_static( type, NA_IFACTORY_OBJECT_TYPE, &ifactory_object_iface_info );
 
 	return( type );
@@ -171,13 +183,13 @@ instance_init( GTypeInstance *instance, gpointer klass )
 	static const gchar *thisfn = "na_object_action_instance_init";
 	NAObjectAction *self;
 
-	g_debug( "%s: instance=%p (%s), klass=%p",
-			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
-
 	g_return_if_fail( NA_IS_OBJECT_ACTION( instance ));
 
 	self = NA_OBJECT_ACTION( instance );
 
+	g_debug( "%s: instance=%p (%s), klass=%p",
+			thisfn, ( void * ) instance, G_OBJECT_TYPE_NAME( instance ), ( void * ) klass );
+
 	self->private = g_new0( NAObjectActionPrivate, 1 );
 }
 
@@ -211,14 +223,14 @@ instance_dispose( GObject *object )
 	static const gchar *thisfn = "na_object_action_instance_dispose";
 	NAObjectAction *self;
 
-	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
 	g_return_if_fail( NA_IS_OBJECT_ACTION( object ));
 
 	self = NA_OBJECT_ACTION( object );
 
 	if( !self->private->dispose_has_run ){
 
+		g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 		self->private->dispose_has_run = TRUE;
 
 		/* chain up to the parent class */
@@ -234,12 +246,12 @@ instance_finalize( GObject *object )
 	static const gchar *thisfn = "na_object_action_instance_finalize";
 	NAObjectAction *self;
 
-	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
-
 	g_return_if_fail( NA_IS_OBJECT_ACTION( object ));
 
 	self = NA_OBJECT_ACTION( object );
 
+	g_debug( "%s: object=%p (%s)", thisfn, ( void * ) object, G_OBJECT_TYPE_NAME( object ));
+
 	g_free( self->private );
 
 	/* chain call to parent class */
@@ -281,7 +293,7 @@ ifactory_object_iface_init( NAIFactoryObjectInterface *iface )
 	iface->copy = NULL;
 	iface->are_equal = ifactory_object_are_equal;
 	iface->is_valid = ifactory_object_is_valid;
-	iface->read_start = ifactory_object_read_start;
+	iface->read_start = NULL;
 	iface->read_done = ifactory_object_read_done;
 	iface->write_start = ifactory_object_write_start;
 	iface->write_done = ifactory_object_write_done;
@@ -313,11 +325,6 @@ ifactory_object_is_valid( const NAIFactoryObject *object )
 	return( object_object_is_valid( NA_OBJECT_ACTION( object )));
 }
 
-static void
-ifactory_object_read_start( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages )
-{
-}
-
 /*
  * at this time, we don't yet have readen the profiles as this will be
  * done in ifactory_provider_read_done - we so just be able to deal with
@@ -326,16 +333,30 @@ ifactory_object_read_start( NAIFactoryObject *instance, const NAIFactoryProvider
 static void
 ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data, GSList **messages )
 {
+	guint iversion;
+
 	g_debug( "na_object_action_ifactory_object_read_done: instance=%p", ( void * ) instance );
 
+	na_object_item_deals_with_version( NA_OBJECT_ITEM( instance ));
+
 	/* may attach a new profile if we detect a pre-v2 action
+	 * the v1_to_v2 conversion must be followed by a v2_to_v3 one
 	 */
-	convert_pre_v2_action( instance );
+	iversion = na_object_get_iversion( instance );
+	if( iversion < 2 ){
+		read_done_convert_v1_to_last( instance );
+	}
 
 	/* deals with obsoleted data, i.e. data which may have been written in the past
-	 * but are no long written by now
+	 * but are no long written by now - not relevant for a menu
 	 */
-	deals_with_toolbar_label( instance );
+	read_done_deals_with_toolbar_label( instance );
+
+	/* prepare the context after the reading
+	 */
+	na_icontext_read_done( NA_ICONTEXT( instance ));
+
+	na_object_dump( instance );
 
 	/* last, set other action defaults
 	 */
@@ -345,7 +366,7 @@ ifactory_object_read_done( NAIFactoryObject *instance, const NAIFactoryProvider
 static guint
 ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages )
 {
-	na_object_item_factory_write_start( NA_OBJECT_ITEM( instance ));
+	na_object_item_rebuild_children_slist( NA_OBJECT_ITEM( instance ));
 
 	return( NA_IIO_PROVIDER_CODE_OK );
 }
@@ -353,97 +374,96 @@ ifactory_object_write_start( NAIFactoryObject *instance, const NAIFactoryProvide
 static guint
 ifactory_object_write_done( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages )
 {
-	static const gchar *thisfn = "na_object_action_ifactory_object_write_done";
 	guint code;
-	GSList *children_slist, *ic;
-	NAObjectProfile *profile;
 
-	code = NA_IIO_PROVIDER_CODE_OK;
+	g_return_val_if_fail( NA_IS_OBJECT_ACTION( instance ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
 
-	if( NA_IS_OBJECT_ACTION( instance )){
-		children_slist = na_object_get_items_slist( instance );
-
-		for( ic = children_slist ; ic && code == NA_IIO_PROVIDER_CODE_OK ; ic = ic->next ){
-			profile = NA_OBJECT_PROFILE( na_object_get_item( instance, ic->data ));
-
-			if( profile ){
-				code = na_ifactory_provider_write_item( writer, writer_data, NA_IFACTORY_OBJECT( profile ), messages );
-
-			} else {
-				g_warning( "%s: profile not found: %s", thisfn, ( const gchar * ) ic->data );
-			}
-		}
-	}
+	code = write_done_write_profiles( instance, writer, writer_data, messages );
 
 	return( code );
 }
 
+static void
+icontext_iface_init( NAIContextInterface *iface )
+{
+	static const gchar *thisfn = "na_object_action_icontext_iface_init";
+
+	g_debug( "%s: iface=%p", thisfn, ( void * ) iface );
+
+	iface->is_candidate = icontext_is_candidate;
+}
+
+static gboolean
+icontext_is_candidate( NAIContext *object, guint target, GList *selection )
+{
+	return( TRUE );
+}
+
 /*
  * do we have a pre-v2 action ?
- *  it may be identified by an version = "1.x"
- *  or by any data found in data_def_action_v1 (defined in na-object-action-factory.c)
- *  -> move obsoleted data to a new profile
+ *  it is be identified by an version = "1.x"
+ *  any data found in data_def_action_v1 (defined in na-object-action-factory.c)
+ *  is obsoleted and moved to a new profile
+ *
+ * actions readen from .desktop already have iversion=3 (cf. desktop_read_start)
+ * and v1 actions may only come from xml or gconf
+ *
+ * returns TRUE if this actually was a v1 action which has been converted to v2
  */
-static void
-convert_pre_v2_action( NAIFactoryObject *instance )
+static gboolean
+read_done_convert_v1_to_last( NAIFactoryObject *instance )
 {
-	gboolean is_pre_v2;
+	static const gchar *thisfn = "na_object_action_read_done_read_done_convert_v1_to_last";
 	GList *to_move;
 	NADataDef *def;
 	NADataBoxed *boxed;
-	gchar *version;
 	GList *ibox;
 	NAObjectProfile *profile;
 
-	is_pre_v2 = FALSE;
+	/* search for old data in the body: this is only possible before profiles
+	 * because starting with contexts, iversion was written
+	 */
 	to_move = NULL;
-
 	def = data_def_action_v1;
+
 	while( def->name ){
 		boxed = na_ifactory_object_get_data_boxed( instance , def->name );
 		if( boxed ){
-			g_debug( "na_object_action_convert_pre_v2_action: " \
-					 "boxed=%p (%s) marked to be moved from action body to profile",
-							 ( void * ) boxed, def->name );
-			to_move =g_list_prepend( to_move, boxed );
+			g_debug( "%s: boxed=%p (%s) marked to be moved from action body to profile",
+							 thisfn, ( void * ) boxed, def->name );
+			to_move = g_list_prepend( to_move, boxed );
 		}
 		def++;
 	}
 
+	if( !to_move ){
+		return( FALSE );
+	}
+
+	/* now create a new profile
+	 */
+	profile = na_object_profile_new();
+	na_object_set_id( profile, "profile-pre-v2" );
+	na_object_set_label( profile, _( "Profile automatically created from pre-v2 action" ));
+	na_object_attach_profile( instance, profile );
+
 	if( to_move ){
-		is_pre_v2 = TRUE;
-
-	} else {
-		version = na_object_get_version( instance );
-		if( version && strlen( version ) && atoi( version ) < 2 ){
-			is_pre_v2 = TRUE;
+		for( ibox = to_move ; ibox ; ibox = ibox->next ){
+			na_factory_object_move_boxed(
+					NA_IFACTORY_OBJECT( profile ), instance, NA_DATA_BOXED( ibox->data ));
 		}
-		g_free( version );
 	}
 
-	if( is_pre_v2 ){
-		profile = na_object_profile_new();
-		na_object_set_id( profile, "profile-pre-v2" );
-		na_object_set_label( profile, _( "Profile automatically created from pre-v2 action" ));
-		na_object_attach_profile( instance, profile );
-
-		if( to_move ){
-			for( ibox = to_move ; ibox ; ibox = ibox->next ){
-				na_factory_object_move_boxed(
-						NA_IFACTORY_OBJECT( profile ), instance, NA_DATA_BOXED( ibox->data ));
-			}
-		}
-
-		na_factory_object_set_defaults( NA_IFACTORY_OBJECT( profile ));
-		na_object_set_last_version( instance );
-	}
+	na_factory_object_set_defaults( NA_IFACTORY_OBJECT( profile ));
+	na_object_profile_convert_v2_to_last( profile );
+	return( TRUE );
 }
 
 /*
  * if toolbar-same-label is true, then ensure that this is actually true
  */
 static void
-deals_with_toolbar_label( NAIFactoryObject *instance )
+read_done_deals_with_toolbar_label( NAIFactoryObject *instance )
 {
 	gchar *toolbar_label;
 	gchar *action_label;
@@ -465,6 +485,35 @@ deals_with_toolbar_label( NAIFactoryObject *instance )
 	g_free( toolbar_label );
 }
 
+/*
+ * write the profiles of the action
+ * note that subitems string list has been rebuilt on write_start
+ */
+static guint
+write_done_write_profiles( NAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data, GSList **messages )
+{
+	static const gchar *thisfn = "na_object_action_write_done_write_profiles";
+	guint code;
+	GSList *children_slist, *ic;
+	NAObjectProfile *profile;
+
+	code = NA_IIO_PROVIDER_CODE_OK;
+	children_slist = na_object_get_items_slist( instance );
+
+	for( ic = children_slist ; ic && code == NA_IIO_PROVIDER_CODE_OK ; ic = ic->next ){
+		profile = NA_OBJECT_PROFILE( na_object_get_item( instance, ic->data ));
+
+		if( profile ){
+			code = na_ifactory_provider_write_item( writer, writer_data, NA_IFACTORY_OBJECT( profile ), messages );
+
+		} else {
+			g_warning( "%s: profile not found: %s", thisfn, ( const gchar * ) ic->data );
+		}
+	}
+
+	return( code );
+}
+
 static gboolean
 object_object_is_valid( const NAObjectAction *action )
 {
@@ -551,6 +600,8 @@ is_valid_toolbar_label( const NAObjectAction *action )
  * but without any profile.
  *
  * Returns: the newly allocated #NAObjectAction object.
+ *
+ * Since: 2.30
  */
 NAObjectAction *
 na_object_action_new( void )
@@ -568,6 +619,8 @@ na_object_action_new( void )
  * Allocates a new #NAObjectAction object along with a default profile.
  *
  * Returns: the newly allocated #NAObjectAction action.
+ *
+ * Since: 2.30
  */
 NAObjectAction *
 na_object_action_new_with_profile( void )
@@ -589,6 +642,8 @@ na_object_action_new_with_profile( void )
  * These two objects have suitable default values.
  *
  * Returns: the newly allocated #NAObjectAction action.
+ *
+ * Since: 2.30
  */
 NAObjectAction *
 na_object_action_new_with_defaults( void )
@@ -619,12 +674,14 @@ na_object_action_new_with_defaults( void )
  * which is not yet allocated. The provided name is so only suitable
  * for the specified @action.
  *
- * Returns: a newly allocated profile name, which should be g_free() by
- * the caller.
- *
  * When inserting a list of profiles in the action, we iter first for
  * new names, before actually do the insertion. We so keep the last
  * allocated name to avoid to allocate the same one twice.
+ *
+ * Returns: a newly allocated profile name, which should be g_free() by
+ * the caller.
+ *
+ * Since: 2.30
  */
 gchar *
 na_object_action_get_new_profile_name( const NAObjectAction *action )
@@ -666,6 +723,8 @@ na_object_action_get_new_profile_name( const NAObjectAction *action )
  * @profile: the #NAObjectProfile profile to be attached to @action.
  *
  * Adds a profile at the end of the list of profiles.
+ *
+ * Since: 2.30
  */
 void
 na_object_action_attach_profile( NAObjectAction *action, NAObjectProfile *profile )
@@ -685,6 +744,8 @@ na_object_action_attach_profile( NAObjectAction *action, NAObjectProfile *profil
  * @action: the #NAObjectAction action to update.
  *
  * Set the version number of the @action to the last one.
+ *
+ * Since: 2.30
  */
 void
 na_object_action_set_last_version( NAObjectAction *action )
@@ -696,32 +757,3 @@ na_object_action_set_last_version( NAObjectAction *action )
 		na_object_set_version( action, "2.0" );
 	}
 }
-
-/**
- * na_object_action_is_candidate:
- * @action: the #NAObjectAction to be tested.
- * @target: the current target.
- * @selection: the current Nautilus selection.
- *
- * Returns: %TRUE if the @action may be candidate for this @target.
- *
- * Note that this public function will become NAIContext::is_candidate
- * when NAObjectAction will implement the interface.
- */
-gboolean
-na_object_action_is_candidate( const NAObjectAction *action, guint target, GList *selection )
-{
-	gboolean is_candidate = FALSE;
-
-	g_return_val_if_fail( NA_IS_OBJECT_ACTION( action ), is_candidate );
-
-	if( !action->private->dispose_has_run ){
-
-		is_candidate =
-			( na_object_is_target_selection( action ) && target == ITEM_TARGET_SELECTION ) ||
-			( na_object_is_target_location( action ) && target == ITEM_TARGET_LOCATION ) ||
-			( na_object_is_target_toolbar( action ) && target == ITEM_TARGET_TOOLBAR );
-	}
-
-	return( is_candidate );
-}
