@@ -32,11 +32,10 @@
 #include <config.h>
 #endif
 
-#include <gdk/gdkkeysyms.h>
-
 #include <api/na-object-api.h>
 
 #include "base-window.h"
+#include "base-keysyms.h"
 #include "nact-main-menubar.h"
 #include "nact-main-tab.h"
 #include "nact-marshal.h"
@@ -1195,22 +1194,22 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, NactIActionsList *i
 	g_debug( "%s: widget=%p, event=%p, user_data=%p", thisfn, widget, event, user_data );*/
 	gboolean stop = FALSE;
 
-	if( event->keyval == GDK_Return || event->keyval == GDK_KP_Enter ){
+	if( event->keyval == NACT_KEY_Return || event->keyval == NACT_KEY_KP_Enter ){
 		nact_iactions_list_bis_toggle_collapse( instance );
 		stop = TRUE;
 	}
 
-	if( event->keyval == GDK_F2 ){
+	if( event->keyval == NACT_KEY_F2 ){
 		inline_edition( instance );
 		stop = TRUE;
 	}
 
-	if( event->keyval == GDK_Right ){
+	if( event->keyval == NACT_KEY_Right ){
 		nact_iactions_list_bis_expand_to_first_child( instance );
 		stop = TRUE;
 	}
 
-	if( event->keyval == GDK_Left ){
+	if( event->keyval == NACT_KEY_Left ){
 		nact_iactions_list_bis_collapse_to_parent( instance );
 		stop = TRUE;
 	}
