@@ -95,8 +95,8 @@ static void              expand_tokens_context( NAIContext *context, NATokens *t
 static GList            *build_nautilus_menus( NautilusActions *plugin, GList *tree, guint target, GList *files, NATokens *tokens );
 static NAObjectProfile  *get_candidate_profile( NautilusActions *plugin, NAObjectAction *action, guint target, GList *files );
 static NautilusMenuItem *create_item_from_profile( NAObjectProfile *profile, guint target, GList *files, NATokens *tokens );
-static NautilusMenuItem *create_item_from_menu( NAObjectMenu *menu, GList *subitems );
-static NautilusMenuItem *create_menu_item( NAObjectItem *item );
+static NautilusMenuItem *create_item_from_menu( NAObjectMenu *menu, GList *subitems, guint target );
+static NautilusMenuItem *create_menu_item( NAObjectItem *item, guint target );
 static void              attach_submenu_to_item( NautilusMenuItem *item, GList *subitems );
 static void              weak_notify_profile( NAObjectProfile *profile, NautilusMenuItem *item );
 
@@ -410,6 +410,10 @@ menu_provider_iface_init( NautilusMenuProviderIface *iface )
  * - either there is zero item selected - current_folder should so be the
  *   folder currently displayed in the file manager view
  * - or when there is only one selected directory
+ *
+ * Note that 'x-nautilus-desktop:///' cannot be interpreted by
+ * #NASelectedInfo::query_file_attributes() function. It so never participate
+ * to the display of actions.
  */
 static GList *
 menu_provider_get_background_items( NautilusMenuProvider *provider, GtkWidget *window, NautilusFileInfo *current_folder )
@@ -423,16 +427,17 @@ menu_provider_get_background_items( NautilusMenuProvider *provider, GtkWidget *w
 
 	if( !NAUTILUS_ACTIONS( provider )->private->dispose_has_run ){
 
-		uri = nautilus_file_info_get_uri( current_folder );
-		g_debug( "%s: provider=%p, window=%p, current_folder=%p (%s)",
-				thisfn, ( void * ) provider, ( void * ) window, ( void * ) current_folder, uri );
-		g_free( uri );
-
 		selected = na_selected_info_get_list_from_item( current_folder );
 
-		nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_LOCATION, selected );
+		if( selected ){
+			uri = nautilus_file_info_get_uri( current_folder );
+			g_debug( "%s: provider=%p, window=%p, current_folder=%p (%s)",
+					thisfn, ( void * ) provider, ( void * ) window, ( void * ) current_folder, uri );
+			g_free( uri );
 
-		na_selected_info_free_list( selected );
+			nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_LOCATION, selected );
+			na_selected_info_free_list( selected );
+		}
 	}
 
 	return( nautilus_menus_list );
@@ -460,14 +465,15 @@ menu_provider_get_file_items( NautilusMenuProvider *provider, GtkWidget *window,
 
 	if( !NAUTILUS_ACTIONS( provider )->private->dispose_has_run ){
 
-		g_debug( "%s: provider=%p, window=%p, files=%p, count=%d",
-				thisfn, ( void * ) provider, ( void * ) window, ( void * ) files, g_list_length( files ));
-
 		selected = na_selected_info_get_list_from_list(( GList * ) files );
 
-		nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_SELECTION, selected );
+		if( selected ){
+			g_debug( "%s: provider=%p, window=%p, files=%p, count=%d",
+					thisfn, ( void * ) provider, ( void * ) window, ( void * ) files, g_list_length( files ));
 
-		na_selected_info_free_list( selected );
+			nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_SELECTION, selected );
+			na_selected_info_free_list( selected );
+		}
 	}
 
 	return( nautilus_menus_list );
@@ -490,16 +496,17 @@ menu_provider_get_toolbar_items( NautilusMenuProvider *provider, GtkWidget *wind
 
 	if( !NAUTILUS_ACTIONS( provider )->private->dispose_has_run ){
 
-		uri = nautilus_file_info_get_uri( current_folder );
-		g_debug( "%s: provider=%p, window=%p, current_folder=%p (%s)",
-				thisfn, ( void * ) provider, ( void * ) window, ( void * ) current_folder, uri );
-		g_free( uri );
-
 		selected = na_selected_info_get_list_from_item( current_folder );
 
-		nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_TOOLBAR, selected );
+		if( selected ){
+			uri = nautilus_file_info_get_uri( current_folder );
+			g_debug( "%s: provider=%p, window=%p, current_folder=%p (%s)",
+					thisfn, ( void * ) provider, ( void * ) window, ( void * ) current_folder, uri );
+			g_free( uri );
 
-		na_selected_info_free_list( selected );
+			nautilus_menus_list = get_menus_items( NAUTILUS_ACTIONS( provider ), ITEM_TARGET_TOOLBAR, selected );
+			na_selected_info_free_list( selected );
+		}
 	}
 
 	return( nautilus_menus_list );
@@ -756,15 +763,16 @@ build_nautilus_menus( NautilusActions *plugin, GList *tree, guint target, GList
 		 */
 		if( NA_IS_OBJECT_MENU( it->data )){
 			subitems = na_object_get_items( it->data );
+			g_debug( "%s: menu has %d items", thisfn, g_list_length( subitems ));
 			submenu = build_nautilus_menus( plugin, subitems, target, files, tokens );
-			/*g_debug( "%s: submenu has %d items", thisfn, g_list_length( submenu ));*/
+			g_debug( "%s: submenu has %d items", thisfn, g_list_length( submenu ));
 
 			if( submenu ){
 				if( target == ITEM_TARGET_TOOLBAR ){
 					menus_list = g_list_concat( menus_list, submenu );
 
 				} else {
-					item = create_item_from_menu( NA_OBJECT_MENU( it->data ), submenu );
+					item = create_item_from_menu( NA_OBJECT_MENU( it->data ), submenu, target );
 					menus_list = g_list_append( menus_list, item );
 				}
 			}
@@ -826,7 +834,7 @@ create_item_from_profile( NAObjectProfile *profile, guint target, GList *files,
 	duplicate = NA_OBJECT_PROFILE( na_object_duplicate( profile ));
 	na_object_set_parent( duplicate, NULL );
 
-	item = create_menu_item( NA_OBJECT_ITEM( action ));
+	item = create_menu_item( NA_OBJECT_ITEM( action ), target );
 
 	/* attach a weak ref on the Nautilus menu item: our profile will be
 	 * unreffed in weak notify function
@@ -863,12 +871,12 @@ weak_notify_profile( NAObjectProfile *profile, NautilusMenuItem *item )
  * we can so safely release our own ref on subitems after this function
  */
 static NautilusMenuItem *
-create_item_from_menu( NAObjectMenu *menu, GList *subitems )
+create_item_from_menu( NAObjectMenu *menu, GList *subitems, guint target )
 {
 	/*static const gchar *thisfn = "nautilus_actions_create_item_from_menu";*/
 	NautilusMenuItem *item;
 
-	item = create_menu_item( NA_OBJECT_ITEM( menu ));
+	item = create_menu_item( NA_OBJECT_ITEM( menu ), target );
 
 	attach_submenu_to_item( item, subitems );
 	nautilus_menu_item_list_free( subitems );
@@ -878,15 +886,14 @@ create_item_from_menu( NAObjectMenu *menu, GList *subitems )
 }
 
 static NautilusMenuItem *
-create_menu_item( NAObjectItem *item )
+create_menu_item( NAObjectItem *item, guint target )
 {
 	NautilusMenuItem *menu_item;
 	gchar *id, *name, *label, *tooltip, *icon;
 
 	id = na_object_get_id( item );
-	name = g_strdup_printf( "%s-%s-%s", PACKAGE, G_OBJECT_TYPE_NAME( item ), id );
+	name = g_strdup_printf( "%s-%s-%s-%d", PACKAGE, G_OBJECT_TYPE_NAME( item ), id, target );
 	label = na_object_get_label( item );
-	/*g_debug( "nautilus_actions_create_menu_item: %s - %s", name, label );*/
 	tooltip = na_object_get_tooltip( item );
 	icon = na_object_get_icon( item );
 
