@@ -45,9 +45,6 @@
 #include <core/na-selected-info.h>
 #include <core/na-tokens.h>
 
-#include <plugin-tracker/na-tracker.h>
-#include <plugin-tracker/na-tracker-dbus.h>
-
 #include "console-utils.h"
 #include "nautilus-actions-run-bindings.h"
 
@@ -152,7 +149,7 @@ main( int argc, char** argv )
 		exit( status );
 	}
 
-	if( !na_icontext_is_candidate( NA_ICONTEXT( action ), ITEM_TARGET_SELECTION, targets )){
+	if( !na_icontext_is_candidate( NA_ICONTEXT( action ), ITEM_TARGET_ANY, targets )){
 		g_printerr( _( "Action %s is not a valid candidate. Exiting.\n" ), id );
 		exit( status );
 	}
@@ -193,12 +190,8 @@ init_options( void )
 	g_option_context_add_main_entries( context, entries, NULL );
 #endif
 
-	description = g_strdup_printf( "%s.\n%s", PACKAGE_STRING,
-			_( "Bug reports are welcomed at http://bugzilla.gnome.org,"
-				" or you may prefer to mail to <maintainer@nautilus-actions.org>.\n" ));
-
+	description = console_cmdline_get_description();
 	g_option_context_set_description( context, description );
-
 	g_free( description );
 
 	misc_group = g_option_group_new(
@@ -228,17 +221,13 @@ get_action( const gchar *id )
 
 	if( !action ){
 		g_printerr( _( "Error: action '%s' doesn't exist.\n" ), id );
-	}
 
-	if( action ){
+	} else {
 		if( !na_object_is_enabled( action )){
 			g_printerr( _( "Error: action '%s' is disabled.\n" ), id );
 			g_object_unref( action );
 			action = NULL;
 		}
-	}
-
-	if( action ){
 		if( !na_object_is_valid( action )){
 			g_printerr( _( "Error: action '%s' is not valid.\n" ), id );
 			g_object_unref( action );
@@ -282,7 +271,9 @@ targets_from_selection( void )
 	g_debug( "%s: connection is ok", thisfn );
 
 	proxy = dbus_g_proxy_new_for_name( connection,
-			NAUTILUS_ACTIONS_DBUS_SERVICE, NA_TRACKER_DBUS_TRACKER_PATH, NA_TRACKER_DBUS_TRACKER_INTERFACE );
+			NAUTILUS_ACTIONS_DBUS_SERVICE,
+			NAUTILUS_ACTIONS_DBUS_TRACKER_PATH,
+			NAUTILUS_ACTIONS_DBUS_TRACKER_INTERFACE );
 
 	if( !proxy ){
 		g_printerr( _( "Error: unable to get a proxy on %s service" ), NAUTILUS_ACTIONS_DBUS_SERVICE );
@@ -336,6 +327,7 @@ get_selection_from_strv( const gchar **strv, gboolean has_mimetype )
 {
 	GList *list;
 	gchar **iter;
+	gchar *errmsg;
 
 	list = NULL;
 	iter = ( gchar ** ) strv;
@@ -347,8 +339,18 @@ get_selection_from_strv( const gchar **strv, gboolean has_mimetype )
 			iter++;
 			mimetype = ( const gchar * ) *iter;
 		}
-		NASelectedInfo *nsi = na_selected_info_create_for_uri( uri, mimetype );
-		list = g_list_prepend( list, nsi );
+
+		errmsg = NULL;
+		NASelectedInfo *nsi = na_selected_info_create_for_uri( uri, mimetype, &errmsg );
+
+		if( errmsg ){
+			g_printerr( "%s\n", errmsg );
+			g_free( errmsg );
+		}
+
+		if( nsi ){
+			list = g_list_prepend( list, nsi );
+		}
 		iter++;
 	}
 
@@ -369,7 +371,7 @@ get_profile_for_targets( NAObjectAction *action, GList *targets )
 	profiles = na_object_get_items( action );
 
 	for( ip = profiles ; ip && !candidate ; ip = ip->next ){
-		if( na_icontext_is_candidate( NA_ICONTEXT( ip->data ), ITEM_TARGET_SELECTION, targets )){
+		if( na_icontext_is_candidate( NA_ICONTEXT( ip->data ), ITEM_TARGET_ANY, targets )){
 			candidate = NA_OBJECT_PROFILE( ip->data );
 		}
 	}
